function F = addnoise(F, noiselevel)
%% ADDNOISE: Adds uniformly distributed complex pseudorandom numbers to the
%       farfield operator such that the relative Frobernius error of the perturbed data
%       is given by noiselevel
%  INPUT:   F - far field operator (ntheta x nd matrix)
%           noiselevel - relative noise level (between 0 and 1)
%  OUTPUT:  F - perturbed far field operator


if noiselevel > 0
    errMat = rand(size(F))-.5+1i*(rand(size(F))-.5); % matrix of u.i.d. numbers between 0 and 1
    errMat = errMat ./ norm(errMat);
    F = F + errMat * noiselevel * norm(F);
    clear errMat
end